==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/sw.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "sw",
    "date_order": "DMY",
    "january": [
        "januari",
        "jan"
    ],
    "february": [
        "februari",
        "feb"
    ],
    "march": [
        "machi",
        "mac"
    ],
    "april": [
        "aprili",
        "apr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "julai",
        "jul"
    ],
    "august": [
        "agosti",
        "ago"
    ],
    "september": [
        "septemba",
        "sep"
    ],
    "october": [
        "oktoba",
        "okt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "desemba",
        "des"
    ],
    "monday": [
        "jumatatu"
    ],
    "tuesday": [
        "jumanne"
    ],
    "wednesday": [
        "jumatano"
    ],
    "thursday": [
        "alhamisi"
    ],
    "friday": [
        "ijumaa"
    ],
    "saturday": [
        "jumamosi"
    ],
    "sunday": [
        "jumapili"
    ],
    "am": [
        "am",
        "asubuhi"
    ],
    "pm": [
        "pm",
        "mchana"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mwezi"
    ],
    "week": [
        "wiki"
    ],
    "day": [
        "siku"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika",
        "dak"
    ],
    "second": [
        "sekunde",
        "sek"
    ],
    "relative-type": {
        "1 year ago": [
            "mwaka uliopita"
        ],
        "0 year ago": [
            "mwaka huu"
        ],
        "in 1 year": [
            "mwaka ujao"
        ],
        "1 month ago": [
            "mwezi uliopita"
        ],
        "0 month ago": [
            "mwezi huu"
        ],
        "in 1 month": [
            "mwezi ujao"
        ],
        "1 week ago": [
            "wiki iliyopita"
        ],
        "0 week ago": [
            "wiki hii"
        ],
        "in 1 week": [
            "wiki ijayo"
        ],
        "1 day ago": [
            "jana"
        ],
        "0 day ago": [
            "leo"
        ],
        "in 1 day": [
            "kesho"
        ],
        "0 hour ago": [
            "saa hii"
        ],
        "0 minute ago": [
            "dakika hii"
        ],
        "0 second ago": [
            "sasa hivi"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "baada ya mwaka (\\d+)",
            "baada ya miaka (\\d+)"
        ],
        "\\1 year ago": [
            "mwaka (\\d+) uliopita",
            "miaka (\\d+) iliyopita"
        ],
        "in \\1 month": [
            "baada ya mwezi (\\d+)",
            "baada ya miezi (\\d+)"
        ],
        "\\1 month ago": [
            "mwezi (\\d+) uliopita",
            "miezi (\\d+) iliyopita"
        ],
        "in \\1 week": [
            "baada ya wiki (\\d+)"
        ],
        "\\1 week ago": [
            "wiki (\\d+) iliyopita",
            "wiki (\\d+) zilizopita"
        ],
        "in \\1 day": [
            "baada ya siku (\\d+)"
        ],
        "\\1 day ago": [
            "siku (\\d+) iliyopita",
            "siku (\\d+) zilizopita"
        ],
        "in \\1 hour": [
            "baada ya saa (\\d+)"
        ],
        "\\1 hour ago": [
            "saa (\\d+) iliyopita",
            "saa (\\d+) zilizopita"
        ],
        "in \\1 minute": [
            "baada ya dakika (\\d+)"
        ],
        "\\1 minute ago": [
            "dakika (\\d+) iliyopita",
            "dakika (\\d+) zilizopita"
        ],
        "in \\1 second": [
            "baada ya sekunde (\\d+)"
        ],
        "\\1 second ago": [
            "sekunde (\\d+) iliyopita",
            "sekunde (\\d+) zilizopita"
        ]
    },
    "locale_specific": {
        "sw-UG": {
            "name": "sw-UG"
        },
        "sw-CD": {
            "name": "sw-CD",
            "week": [
                "juma"
            ]
        },
        "sw-KE": {
            "name": "sw-KE"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/sw.py <==
info = {
    "name": "sw",
    "date_order": "DMY",
    "january": [
        "jan",
        "januari"
    ],
    "february": [
        "feb",
        "februari"
    ],
    "march": [
        "mac",
        "machi"
    ],
    "april": [
        "apr",
        "aprili"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "julai"
    ],
    "august": [
        "ago",
        "agosti"
    ],
    "september": [
        "sep",
        "septemba"
    ],
    "october": [
        "okt",
        "oktoba"
    ],
    "november": [
        "nov",
        "novemba"
    ],
    "december": [
        "des",
        "desemba"
    ],
    "monday": [
        "jumatatu"
    ],
    "tuesday": [
        "jumanne"
    ],
    "wednesday": [
        "jumatano"
    ],
    "thursday": [
        "alhamisi"
    ],
    "friday": [
        "ijumaa"
    ],
    "saturday": [
        "jumamosi"
    ],
    "sunday": [
        "jumapili"
    ],
    "am": [
        "am",
        "asubuhi"
    ],
    "pm": [
        "mchana",
        "pm"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mwezi"
    ],
    "week": [
        "wiki"
    ],
    "day": [
        "siku"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dak",
        "dakika"
    ],
    "second": [
        "sek",
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "leo"
        ],
        "0 hour ago": [
            "saa hii"
        ],
        "0 minute ago": [
            "dakika hii"
        ],
        "0 month ago": [
            "mwezi huu"
        ],
        "0 second ago": [
            "sasa hivi"
        ],
        "0 week ago": [
            "wiki hii"
        ],
        "0 year ago": [
            "mwaka huu"
        ],
        "1 day ago": [
            "jana"
        ],
        "1 month ago": [
            "mwezi uliopita"
        ],
        "1 week ago": [
            "wiki iliyopita"
        ],
        "1 year ago": [
            "mwaka uliopita"
        ],
        "in 1 day": [
            "kesho"
        ],
        "in 1 month": [
            "mwezi ujao"
        ],
        "in 1 week": [
            "wiki ijayo"
        ],
        "in 1 year": [
            "mwaka ujao"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "siku (\\d+) iliyopita",
            "siku (\\d+) zilizopita"
        ],
        "\\1 hour ago": [
            "saa (\\d+) iliyopita",
            "saa (\\d+) zilizopita"
        ],
        "\\1 minute ago": [
            "dakika (\\d+) iliyopita",
            "dakika (\\d+) zilizopita"
        ],
        "\\1 month ago": [
            "miezi (\\d+) iliyopita",
            "mwezi (\\d+) uliopita"
        ],
        "\\1 second ago": [
            "sekunde (\\d+) iliyopita",
            "sekunde (\\d+) zilizopita"
        ],
        "\\1 week ago": [
            "wiki (\\d+) iliyopita",
            "wiki (\\d+) zilizopita"
        ],
        "\\1 year ago": [
            "miaka (\\d+) iliyopita",
            "mwaka (\\d+) uliopita"
        ],
        "in \\1 day": [
            "baada ya siku (\\d+)"
        ],
        "in \\1 hour": [
            "baada ya saa (\\d+)"
        ],
        "in \\1 minute": [
            "baada ya dakika (\\d+)"
        ],
        "in \\1 month": [
            "baada ya miezi (\\d+)",
            "baada ya mwezi (\\d+)"
        ],
        "in \\1 second": [
            "baada ya sekunde (\\d+)"
        ],
        "in \\1 week": [
            "baada ya wiki (\\d+)"
        ],
        "in \\1 year": [
            "baada ya miaka (\\d+)",
            "baada ya mwaka (\\d+)"
        ]
    },
    "locale_specific": {
        "sw-CD": {
            "name": "sw-CD",
            "week": [
                "juma"
            ]
        },
        "sw-KE": {
            "name": "sw-KE"
        },
        "sw-UG": {
            "name": "sw-UG"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
